
package org.objectweb.fractal.bf.adl.exporter;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.bf.adl.common.BindingFactoryLoader;
import org.objectweb.fractal.bf.adl.common.ParameterContainer;
import org.objectweb.fractal.bf.adl.common.ParameterVerifier;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * A loader for <exporter> nodes.
 */
public class ExporterLoader extends BindingFactoryLoader
{

  Logger log = LoggerFactory.getLogger(ExporterLoader.class);

  /**
   * @see org.objectweb.fractal.bf.adl.common.BindingFactoryLoader#performSpecificChecksOn(java.lang.Object)
   */
  @Override
  protected void performSpecificChecksOn(Object node) throws ADLException
  {
    if (node instanceof ExporterContainer)
    {
      ExporterContainer exporterContainer = (ExporterContainer) node;
      final Exporter[] exporters = exporterContainer.getExporters();
      if (exporters.length > 0)
      {
        for (Exporter exp : exporters)
        {
          if (exp.getType() == null || exp.getType().equalsIgnoreCase(""))
          {
            throw new ADLException(
                "The type of the exporter to use can't be empty");
          }
          if (exp.getInterface() == null
              || exp.getInterface().equalsIgnoreCase(""))
          {
            throw new ADLException(
                "Interface to be used by the exporter missing");
          }
          else
          {
            String itf = exp.getInterface();
            int dot = itf.lastIndexOf(".");
            String componentName = itf.substring(0, dot);
            String itfName = itf.substring(dot + 1);
            log.info("Exporter will export interface '" + itfName
                + "' of component '" + componentName + "'");
          }

          if (exp instanceof ParameterContainer)
          {

            ParameterContainer pc = (ParameterContainer) exp;
            ParameterVerifier.verify(pc);

          }
        }

      }
    }

  }

}
